@@ -26,19 +26,34 @@ BcdClockWidget::BcdClockWidget(QWidget *parent) :
 {
     layout = new QHBoxLayout(this);
 
-    secondsOneWidget = new VerticalBinaryDisplayWidget(4, 1);
-    secondsTenWidget = new VerticalBinaryDisplayWidget(3, 2, 4);
-    minutesOneWidget = new VerticalBinaryDisplayWidget(4, 3);
-    minutesTenWidget = new VerticalBinaryDisplayWidget(3, 4, 4);
-    hoursOneWidget = new VerticalBinaryDisplayWidget(4, 1);
     hoursTenWidget = new VerticalBinaryDisplayWidget(2, 2, 4);
-
+    connect(this, SIGNAL(settingsChanged()), hoursTenWidget, SLOT(applySettings()));
     layout->addWidget(hoursTenWidget);
+
+    hoursOneWidget = new VerticalBinaryDisplayWidget(4, 1);
+    connect(this, SIGNAL(settingsChanged()), hoursOneWidget, SLOT(applySettings()));
     layout->addWidget(hoursOneWidget);
+
+    minutesTenWidget = new VerticalBinaryDisplayWidget(3, 4, 4);
+    connect(this, SIGNAL(settingsChanged()), minutesTenWidget, SLOT(applySettings()));
     layout->addWidget(minutesTenWidget);
+
+    minutesOneWidget = new VerticalBinaryDisplayWidget(4, 3);
+    connect(this, SIGNAL(settingsChanged()), minutesOneWidget, SLOT(applySettings()));
     layout->addWidget(minutesOneWidget);
-    layout->addWidget(secondsTenWidget);
-    layout->addWidget(secondsOneWidget);
+
+    if(showSeconds){
+        secondsTenWidget = new VerticalBinaryDisplayWidget(3, 2, 4);
+        connect(this, SIGNAL(settingsChanged()), secondsTenWidget, SLOT(applySettings()));
+        layout->addWidget(secondsTenWidget);
+
+        secondsOneWidget = new VerticalBinaryDisplayWidget(4, 1);
+        connect(this, SIGNAL(settingsChanged()), secondsOneWidget, SLOT(applySettings()));
+        layout->addWidget(secondsOneWidget);
+    }else{
+        secondsOneWidget = NULL;
+        secondsTenWidget = NULL;
+    }
 
     setFixedSize(sizeHint());
     layout->setSizeConstraint(QLayout::SetMinimumSize);
@@ -47,8 +62,12 @@ BcdClockWidget::BcdClockWidget(QWidget *parent) :
 }
 
 BcdClockWidget::~BcdClockWidget(){
-    delete secondsOneWidget;
-    delete secondsTenWidget;
+    if(secondsOneWidget != NULL){
+        delete secondsOneWidget;
+    }
+    if(secondsTenWidget != NULL){
+        delete secondsTenWidget;
+    }
     delete minutesOneWidget;
     delete minutesTenWidget;
     delete hoursOneWidget;
@@ -57,36 +76,9 @@ BcdClockWidget::~BcdClockWidget(){
     delete layout;
 }
 
-void BcdClockWidget::setLedSize(int size){
-    secondsOneWidget->setLedSize(size);
-    secondsTenWidget->setLedSize(size);
-    minutesOneWidget->setLedSize(size);
-    minutesTenWidget->setLedSize(size);
-    hoursOneWidget->setLedSize(size);
-    hoursTenWidget->setLedSize(size);
-}
-
-void BcdClockWidget::setLedBorder(int border){
-    secondsOneWidget->setLedBorder(border);
-    secondsTenWidget->setLedBorder(border);
-    minutesOneWidget->setLedBorder(border);
-    minutesTenWidget->setLedBorder(border);
-    hoursOneWidget->setLedBorder(border);
-    hoursTenWidget->setLedBorder(border);
-}
-
-void BcdClockWidget::setLedColor(const QColor &color){
-    secondsOneWidget->setLedColor(color);
-    secondsTenWidget->setLedColor(color);
-    minutesOneWidget->setLedColor(color);
-    minutesTenWidget->setLedColor(color);
-    hoursOneWidget->setLedColor(color);
-    hoursTenWidget->setLedColor(color);
-}
-
 QSize BcdClockWidget::sizeHint(){
-    return QSize((6 * secondsOneWidget->getElementSize()) + (2 * layout->margin()) + 35,
-                 (4 * secondsOneWidget->getElementSize()) + (2 * layout->margin())
+    return QSize((((showSeconds) ? 6 : 4) * hoursOneWidget->getElementSize()) + (2 * layout->margin()) + 35,
+                 (4 * hoursOneWidget->getElementSize()) + (2 * layout->margin())
 #ifdef Q_WS_MAEMO_5
                  + 6
 #endif
@@ -96,8 +88,12 @@ QSize BcdClockWidget::sizeHint(){
 void BcdClockWidget::updateTime(){
     QTime time = QTime::currentTime();
 
-    secondsOneWidget->updateValue(time.second() % 10);
-    secondsTenWidget->updateValue(time.second() / 10);
+    if(secondsOneWidget != NULL){
+        secondsOneWidget->updateValue(time.second() % 10);
+    }
+    if(secondsTenWidget != NULL){
+        secondsTenWidget->updateValue(time.second() / 10);
+    }
     minutesOneWidget->updateValue(time.minute() % 10);
     minutesTenWidget->updateValue(time.minute() / 10);
     hoursOneWidget->updateValue(time.hour() % 10);
