@@ -17,22 +17,32 @@
  *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QSettings>
 #include <QTime>
 
 #include "binaryclockwidget.h"
+#include "settingsdialog.h"
 
 BinaryClockWidget::BinaryClockWidget(QWidget *parent) :
     ClockWidget(parent)
 {
     layout = new QVBoxLayout(this);
 
-    secondsWidget = new HorizontalBinaryDisplayWidget(6, 1);
-    minutesWidget = new HorizontalBinaryDisplayWidget(6, 2);
     hoursWidget = new HorizontalBinaryDisplayWidget(5, 3, 6);
-
+    connect(this, SIGNAL(settingsChanged()), hoursWidget, SLOT(applySettings()));
     layout->addWidget(hoursWidget);
+
+    minutesWidget = new HorizontalBinaryDisplayWidget(6, 2);
+    connect(this, SIGNAL(settingsChanged()), minutesWidget, SLOT(applySettings()));
     layout->addWidget(minutesWidget);
-    layout->addWidget(secondsWidget);
+
+    if(showSeconds){
+        secondsWidget = new HorizontalBinaryDisplayWidget(6, 1);
+        connect(this, SIGNAL(settingsChanged()), secondsWidget, SLOT(applySettings()));
+        layout->addWidget(secondsWidget);
+    }else{
+        secondsWidget = NULL;
+    }
 
     setFixedSize(sizeHint());
     layout->setSizeConstraint(QLayout::SetMinimumSize);
@@ -41,44 +51,30 @@ BinaryClockWidget::BinaryClockWidget(QWidget *parent) :
 }
 
 BinaryClockWidget::~BinaryClockWidget(){
-    delete secondsWidget;
+    if(secondsWidget != NULL){
+        delete secondsWidget;
+    }
     delete minutesWidget;
     delete hoursWidget;
 
     delete layout;
 }
 
-void BinaryClockWidget::setLedSize(int size){
-    secondsWidget->setLedSize(size);
-    minutesWidget->setLedSize(size);
-    hoursWidget->setLedSize(size);
-}
-
-void BinaryClockWidget::setLedBorder(int border){
-    secondsWidget->setLedBorder(border);
-    minutesWidget->setLedBorder(border);
-    hoursWidget->setLedBorder(border);
-}
-
-void BinaryClockWidget::setLedColor(const QColor &color){
-    secondsWidget->setLedColor(color);
-    minutesWidget->setLedColor(color);
-    hoursWidget->setLedColor(color);
-}
-
 QSize BinaryClockWidget::sizeHint(){
-    return QSize((6 * (secondsWidget->getElementSize())) + (2 * layout->margin())
+    return QSize((6 * (hoursWidget->getElementSize())) + (2 * layout->margin())
 #ifdef Q_WS_MAEMO_5
                  + 35
 #endif
                  ,
-                 (3 * secondsWidget->getElementSize()) + (2 * layout->margin()) + 6);
+                 (((showSeconds) ? 3 : 2) * hoursWidget->getElementSize()) + (2 * layout->margin()) + 6);
 }
 
 void BinaryClockWidget::updateTime(){
     QTime time = QTime::currentTime();
 
-    secondsWidget->updateValue(time.second());
+    if(secondsWidget != NULL){
+        secondsWidget->updateValue(time.second());
+    }
     minutesWidget->updateValue(time.minute());
     hoursWidget->updateValue(time.hour());
 }
