@@ -35,6 +35,9 @@ const int SettingsDialog::LED_BORDER_DEFAULT = 8;
 const QString SettingsDialog::LED_SIZE = "led_size";
 const int SettingsDialog::LED_SIZE_DEFAULT = 34;
 
+const QString SettingsDialog::SHOW_SECONDS = "show_seconds";
+const bool SettingsDialog::SHOW_SECONDS_DEFAULT = true;
+
 #ifndef Q_WS_MAEMO_5
 const QString SettingsDialog::POSITION = "position";
 const QPoint SettingsDialog::POSITION_DEFAULT = QPoint(10, 10);
@@ -67,6 +70,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
                                              SettingsDialog::LED_BORDER_DEFAULT).toInt());
     ui->ledSizeSpinBox->setValue(settings.value(SettingsDialog::LED_SIZE,
                                              SettingsDialog::LED_SIZE_DEFAULT).toInt());
+    ui->showSecondsCheckBox->setChecked(settings.value(SettingsDialog::SHOW_SECONDS,
+                                                       SettingsDialog::SHOW_SECONDS_DEFAULT).toBool());
 
 #ifndef Q_WS_MAEMO_5
     ui->transparencySupportCheckBox->setChecked(settings.value(SettingsDialog::TRANSPARENCY,
@@ -103,6 +108,8 @@ void SettingsDialog::accept(){
     settings.setValue(SettingsDialog::LED_BORDER, ui->ledBorderSpinBox->value());
     settings.setValue(SettingsDialog::LED_SIZE, ui->ledSizeSpinBox->value());
 
+    settings.setValue(SettingsDialog::SHOW_SECONDS, ui->showSecondsCheckBox->isChecked());
+
 #ifndef Q_WS_MAEMO_5
     settings.setValue(SettingsDialog::TRANSPARENCY, ui->transparencySupportCheckBox->isChecked());
     settings.setValue(SettingsDialog::WIDGET_PLACEMENT, ui->widgetPlacementComboBox->currentIndex());
